@@ -21,6 +21,7 @@ function squirrelmail_plugin_init_select_range(){
     $squirrelmail_plugin_hooks['optpage_loadhook_display']['select_range'] = 'select_range_options';
     $squirrelmail_plugin_hooks['mailbox_selectall_after']['select_range'] = 'select_range_return_link';
     $squirrelmail_plugin_hooks['addressbook_before_list']['select_range'] = 'select_range_abook';
+    $squirrelmail_plugin_hooks['list_checkbox_extra_params']['select_range'] = 'select_range_checkbox_params';
 }
 
 function select_range_abook(){
@@ -43,6 +44,12 @@ function select_range_return_link(){
     return( select_range_do_print( 1, '&nbsp;&nbsp;' ) );
 }
 
+function select_range_checkbox_params($params){
+    list($element_name,$always_show) = $params;
+    include_once( SM_PATH . 'plugins/select_range/functions.php' );
+    return( select_range_do_checkbox_params($element_name,$always_show) );
+}
+
 function select_range_version(){
     // untested code, hope it works...
 	 $return_val;
